ui

package
v0.0.0-...-9a5b88c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 12, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package ui provides the terminal user interface using the BubbleTea framework. It includes views for tunnel management, groups, and help.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(manager *tunnel.Manager, configPath string) error

Run starts the application

Types

type App

type App struct {
	// contains filtered or unexported fields
}

App represents the main application model

func NewApp

func NewApp(manager *tunnel.Manager, configPath string) *App

NewApp creates a new application

func (*App) Init

func (a *App) Init() tea.Cmd

Init initializes the application

func (*App) Update

func (a *App) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update handles messages

func (*App) View

func (a *App) View() string

View renders the application

Directories

Path Synopsis
Package components provides reusable UI components for the terminal interface.
Package components provides reusable UI components for the terminal interface.
Package messages defines the message types used for communication between UI components.
Package messages defines the message types used for communication between UI components.
Package styles defines the visual styling for the terminal UI using lipgloss.
Package styles defines the visual styling for the terminal UI using lipgloss.
Package views implements the different screens of the terminal UI.
Package views implements the different screens of the terminal UI.

Jump to